@@ -1,7 +1,7 @@
 import sqlalchemy as sa
 from sqlalchemy_utils.functions import create_database
-from pyg_base import cfg_read, dumps, loads, as_list, dictable, Dict, is_dict, is_dictable, is_strs, is_str, is_int, is_date, dt2str, ulist, try_back, unique, encode, decode
-from pyg_encoders import as_reader, as_writer
+from pyg_base import cfg_read, as_list, dictable, Dict, is_dict, is_dictable, is_strs, is_str, is_int, is_date, dt2str, ulist, try_back, unique
+from pyg_encoders import as_reader, as_writer, dumps, loads, encode, decode
 from sqlalchemy import Table, Column, Integer, String, MetaData, Identity, Float, DATE, DATETIME, TIME, select, func, not_, desc, asc
 from sqlalchemy.orm import Session
 import datetime
@@ -143,11 +143,17 @@ def sql_table(table, db = None, non_null = None, nullable = None, _id = None, sc
     pks = pk or {}
     if isinstance(pks, list):
         pks = {k : String for k in pks}
+    elif isinstance(pks, str):
+        pks = {pks : String}
     if isinstance(non_null, list):
         non_null = {k : String for k in non_null}
+    elif isinstance(non_null, str):
+        non_null = {non_null : String}
     pks.update(non_null)
     if isinstance(nullable, list):
         nullable = {k : String for k in nullable}
+    elif isinstance(nullable, str):
+        nullable = {nullable: String}
     if isinstance(table, str):
         table_name = table 
     else:
@@ -1162,7 +1168,8 @@ class sql_cursor(object):
         for k,v in params.items():
             text = text.replace(':'+k, '"%s"'%v if is_str(v) else dt2str(v) if is_date(v) else str(v))
             
-        res = 'sql_cursor: %(db)s.%(table)s%(pk)s %(doc)s\n%(statement)s\n%(n)i records'%dict(db = self.db, table = self.table.name, doc = 'DOCSTORE[%s]'%self.doc if self.doc else '', 
+        res = 'sql_cursor: %(db)s.%(table)s%(pk)s %(doc)s %(w)s\n%(statement)s\n%(n)i records'%dict(db = self.db, table = self.table.name, doc = 'DOCSTORE[%s]'%self.doc if self.doc else '', 
+                                                                                              w = 'writer = %s'%self.writer if is_str(self.writer) else '',
                                                                                               pk = self._pk if self._pk else '', 
                                                                                               n = len(self), 
                                                                                               statement = text)
